# Changelog

## [1.0.1a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/1.0.1a1) (2024-10-16)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/1.0.0...1.0.1a1)

**Merged pull requests:**

- fix:standardize lang code [\#254](https://github.com/OpenVoiceOS/OVOS-workshop/pull/254) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
